# Burmese Date

**Burmese Calender API in Python**

---

![logo](https://upload.wikimedia.org/wikipedia/commons/d/d7/WikiProject_Myanmar_peacock.svg)

---

**The Burmese calendar has a long and rich history, dating back over 2,000 years. It is closely tied to Buddhist tradition and is used to mark important religious festivals and events.**

---

<p style="color: red;">Important Note ::  To calculate the future years for the Burmese calendar,only depends on the full moon day of Second Waso in this project. But officially announced dates still depend on the Calendar Advisory Board of The Republic of Union of Myanmar. More detail,  <a href="https://shorturl.at/fD478" target="_blank"> Algorithm, Program and Calculation of Myanmar Calendar</a>.</p>

---


### Acknowledgement

This project is totally base on :

- Javascript : https://github.com/yan9a/mmcal/blob/master/javascript/ceMmDateTime.js

- C++ : https://github.com/yan9a/mmcal/blob/master/cpp/src/ceMmDateTime.cpp.

---
**Project is still in progress.**



### LICENSE

MIT : https://opensource.org/license/MIT